==> haskell-hspec-hedgehog-0.0.1.2-367.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-hedgehog
version:              0.0.1.2
visibility:           public
id:                   hspec-hedgehog-0.0.1.2-3k8wJN4FUEwK6AI6cCwtG8
key:                  hspec-hedgehog-0.0.1.2-3k8wJN4FUEwK6AI6cCwtG8
license:              BSD-3-Clause
copyright:            2020 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/hspec-hedgehog#readme
synopsis:             Integrate Hedgehog and Hspec!
description:
    Please see the README on GitHub at <https://github.com/parsonsmatt/hspec-hedgehog#readme>

category:             Testing
abi:                  4a8d64fd3798d1c0d94d5716af32afcb
exposed:              True
exposed-modules:      Test.Hspec.Hedgehog
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-hedgehog
hs-libraries:         HShspec-hedgehog-0.0.1.2-3k8wJN4FUEwK6AI6cCwtG8
depends:
    HUnit-1.6.2.0-IE0oFrOTEOHIkscEaBk8om
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    hedgehog-1.5-1xA9En5y6Uc9YP36VbJg3a
    hspec-2.11.4-2r49l9VEKrJ4fH7w2ReGM6
    hspec-core-2.11.4-1HkLPyupJ0H3VqtAEeRZWL
    splitmix-0.1.3-9CESEz75Upa7nQgfltLRDI

haddock-interfaces:
    /usr/share/doc/haskell-hspec-hedgehog/html/hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-hedgehog-0.0.1.2-368-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-hedgehog
version:              0.0.1.2
visibility:           public
id:                   hspec-hedgehog-0.0.1.2-2wqxCGr31Hf9wefCvjT7mW
key:                  hspec-hedgehog-0.0.1.2-2wqxCGr31Hf9wefCvjT7mW
license:              BSD-3-Clause
copyright:            2020 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/hspec-hedgehog#readme
synopsis:             Integrate Hedgehog and Hspec!
description:
    Please see the README on GitHub at <https://github.com/parsonsmatt/hspec-hedgehog#readme>

category:             Testing
abi:                  6ce130ca11047cccace21b5d06fc2a23
exposed:              True
exposed-modules:      Test.Hspec.Hedgehog
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-hedgehog
hs-libraries:         HShspec-hedgehog-0.0.1.2-2wqxCGr31Hf9wefCvjT7mW
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    hedgehog-1.5-BwlqoHTHZqU94Z0NM4guvO
    hspec-2.11.4-8QgnQwrEho14jh62SRkWei
    hspec-core-2.11.4-LH4ljAyFr7833CkU966kHA
    splitmix-0.1.3-90QrqABg5SpKi5FtNwnDR8

haddock-interfaces:
    /usr/share/doc/haskell-hspec-hedgehog/html/hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
